==> qtjambi-activex-6.3.3-sources.jar: io/qt/activex/QAxSelect.java <==
package io.qt.activex;


/**
 * <p>Selection dialog for registered COM components</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qaxselect.html">QAxSelect</a></p>
 */
public class QAxSelect extends io.qt.widgets.QDialog
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QAxSelect.class);
    
    /**
     * <p>Java wrapper for Qt enum <a href="https://doc.qt.io/qt/qaxselect.html#SandboxingLevel-enum">QAxSelect::SandboxingLevel</a></p>
     */
    @io.qt.QtUnlistedEnum
    public enum SandboxingLevel implements io.qt.QtEnumerator {
        SandboxingNone(0),
        SandboxingProcess(1),
        SandboxingLowIntegrity(2);

        private SandboxingLevel(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static SandboxingLevel resolve(int value) {
            switch (value) {
            case 0: return SandboxingNone;
            case 1: return SandboxingProcess;
            case 2: return SandboxingLowIntegrity;
            default: throw new io.qt.QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    
    
    /**
     * <p>Overloaded constructor for {@link #QAxSelect(io.qt.widgets.QWidget, io.qt.core.Qt.WindowFlags)}.</p>
     */
    public QAxSelect(io.qt.widgets.QWidget parent, io.qt.core.Qt.WindowType ... flags){
        this(parent, new io.qt.core.Qt.WindowFlags(flags));
    }
    
    /**
     * <p>Overloaded constructor for {@link #QAxSelect(io.qt.widgets.QWidget, io.qt.core.Qt.WindowFlags)}
     *  with <code>flags = new io.qt.core.Qt.WindowFlags(0)</code>.</p>
     */
    public QAxSelect(io.qt.widgets.QWidget parent) {
        this(parent, new io.qt.core.Qt.WindowFlags(0));
    }
    
    /**
     * <p>Overloaded constructor for {@link #QAxSelect(io.qt.widgets.QWidget, io.qt.core.Qt.WindowFlags)}</p>
     * <p>with: </p><ul>
     * <li><code>parent = null</code></li>
     * <li><code>flags = new io.qt.core.Qt.WindowFlags(0)</code></li>
     * </ul>
     */
    public QAxSelect() {
        this((io.qt.widgets.QWidget)null, new io.qt.core.Qt.WindowFlags(0));
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxselect.html#QAxSelect">QAxSelect::QAxSelect(QWidget*,Qt::WindowFlags)</a></p>
     */
    public QAxSelect(io.qt.widgets.QWidget parent, io.qt.core.Qt.WindowFlags flags){
        super((QPrivateConstructor)null);
        initialize_native(this, parent, flags);
    }
    
    private native static void initialize_native(QAxSelect instance, io.qt.widgets.QWidget parent, io.qt.core.Qt.WindowFlags flags);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxselect.html#clsid">QAxSelect::clsid()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String clsid(){
        return clsid_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String clsid_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxselect.html#sandboxingLevel">QAxSelect::sandboxingLevel()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.activex.QAxSelect.SandboxingLevel sandboxingLevel(){
        return io.qt.activex.QAxSelect.SandboxingLevel.resolve(sandboxingLevel_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int sandboxingLevel_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QAxSelect(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QAxSelect(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QAxSelect instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-activex-6.4.0-sources.jar: io/qt/activex/QAxSelect.java <==
package io.qt.activex;


/**
 * <p>Selection dialog for registered COM components</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qaxselect.html">QAxSelect</a></p>
 */
public class QAxSelect extends io.qt.widgets.QDialog
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QAxSelect.class);
    
    /**
     * <p>Java wrapper for Qt enum <a href="https://doc.qt.io/qt/qaxselect.html#SandboxingLevel-enum">QAxSelect::SandboxingLevel</a></p>
     */
    @io.qt.QtUnlistedEnum
    public enum SandboxingLevel implements io.qt.QtEnumerator {
        SandboxingNone(0),
        SandboxingProcess(1),
        SandboxingLowIntegrity(2);

        private SandboxingLevel(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static SandboxingLevel resolve(int value) {
            switch (value) {
            case 0: return SandboxingNone;
            case 1: return SandboxingProcess;
            case 2: return SandboxingLowIntegrity;
            default: throw new io.qt.QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    
    
    /**
     * <p>Overloaded constructor for {@link #QAxSelect(io.qt.widgets.QWidget, io.qt.core.Qt.WindowFlags)}.</p>
     */
    public QAxSelect(io.qt.widgets.QWidget parent, io.qt.core.Qt.WindowType ... flags){
        this(parent, new io.qt.core.Qt.WindowFlags(flags));
    }
    
    /**
     * <p>Overloaded constructor for {@link #QAxSelect(io.qt.widgets.QWidget, io.qt.core.Qt.WindowFlags)}
     *  with <code>flags = new io.qt.core.Qt.WindowFlags(0)</code>.</p>
     */
    public QAxSelect(io.qt.widgets.QWidget parent) {
        this(parent, new io.qt.core.Qt.WindowFlags(0));
    }
    
    /**
     * <p>Overloaded constructor for {@link #QAxSelect(io.qt.widgets.QWidget, io.qt.core.Qt.WindowFlags)}</p>
     * <p>with: </p><ul>
     * <li><code>parent = null</code></li>
     * <li><code>flags = new io.qt.core.Qt.WindowFlags(0)</code></li>
     * </ul>
     */
    public QAxSelect() {
        this((io.qt.widgets.QWidget)null, new io.qt.core.Qt.WindowFlags(0));
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxselect.html#QAxSelect">QAxSelect::QAxSelect(QWidget*,Qt::WindowFlags)</a></p>
     */
    public QAxSelect(io.qt.widgets.QWidget parent, io.qt.core.Qt.WindowFlags flags){
        super((QPrivateConstructor)null);
        initialize_native(this, parent, flags);
    }
    
    private native static void initialize_native(QAxSelect instance, io.qt.widgets.QWidget parent, io.qt.core.Qt.WindowFlags flags);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxselect.html#clsid">QAxSelect::clsid()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String clsid(){
        return clsid_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String clsid_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxselect.html#sandboxingLevel">QAxSelect::sandboxingLevel()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.activex.QAxSelect.SandboxingLevel sandboxingLevel(){
        return io.qt.activex.QAxSelect.SandboxingLevel.resolve(sandboxingLevel_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int sandboxingLevel_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QAxSelect(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QAxSelect(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QAxSelect instance, QDeclarativeConstructor constructor);
    
}
